% eegplugin_besa() - EEGLAB plugin for finding component source dipole models
%                    using BESA (Brain Electric Source Analysis, Megis Software, 
%                    Munich) version 3.0. (Later versions do not have batch mode
%                    scripting. Version 2.2 may work as well).
% Usage:
%   >> eegplugin_besa(menu);
%   >> eegplugin_besa(menu, trystrs, catchstrs);
%
% Inputs:
%   menu       - [float]  EEGLAB menu handle
%   trystrs    - [struct] "try" strings for menu callbacks. See notes. 
%   catchstrs  - [struct] "catch" strings for menu callbacks. See notes. 
%
% Notes:
%   To create a new plugin, simply create a file beginning with "eegplugin_"
%   and place it in your eeglab folder. It will then be automatically 
%   detected by eeglab. 
%   For eeglab to return errors and add the function's results to 
%   the eeglab history, menu callback must be nested into "try" and 
%   a "catch" strings. For more information on how to create eeglab 
%   plugins, see http://www.sccn.ucsd.edu/eeglab/contrib.html
%
% Author: Arnaud Delorme, CNL / Salk Institute, 22 February 2003
%
% See also: eeglab()

%123456789012345678901234567890123456789012345678901234567890123456789012

% Copyright (C) 2003 Arnaud Delorme, Salk Institute, arno@salk.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: eegplugin_besa.m,v $
% Revision 1.7  2003/03/12 00:38:41  arno
% error calling dipplot
%
% Revision 1.6  2003/03/12 00:37:47  arno
% new check
%
% Revision 1.5  2003/03/11 23:35:04  arno
% update for pop_dipplot.m
%
% Revision 1.4  2003/02/26 17:03:15  arno
% besaplot -> dipplot
%
% Revision 1.3  2003/02/25 01:11:02  scott
% header edit -sm
%
% Revision 1.2  2003/02/24 19:35:52  arno
% adding besa plugin
%
% Revision 1.1  2003/02/24 19:32:24  arno
% Initial revision
%

function eegplugin_besa(menu, trystrs, catchstrs)
    
    if nargin < 3
        error('eegplugin_besa requires 3 arguments');
    end;
    
    % command to check that the '.source' is present in the EEG structure 
    % -------------------------------------------------------------------
    check_besa = [ 'if ~isfield(EEG, ''sources''), error(''No dipole information in dataset''); end;'  ...
                 trystrs.no_check ];
    
    % menu callback commands
    % ----------------------
    comexport = [ trystrs.check_ica 'besaexport(EEG);' catchstrs.add_to_hist ]; 
    comimport = [ trystrs.check_ica 'EEG = besaimport(EEG);' catchstrs.store_and_hist ];
    complot1  = [ check_besa 'pop_dipplot(EEG);' catchstrs.add_to_hist ];
    
    % create menus
    % ------------
    submenu = uimenu( menu, 'Label', 'Locate dipoles using BESA');
    uimenu( submenu, 'Label', 'Export components to BESA'     , 'CallBack', comexport);
    uimenu( submenu, 'Label', 'Import dipoles from BESA'      , 'CallBack', comimport);
    uimenu( submenu, 'Label', 'Plot dipoles on BESA head'     , 'CallBack', complot1);
 